@@ -10,7 +10,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -699,7 +699,7 @@ ag_scm_raw_shell_str(SCM obj)
 SCM
 ag_scm_shell_str(SCM obj)
 {
-    return shell_stringify(obj, (unsigned)'"');
+    return shell_stringify(obj, (unsigned char)'"');
 }
 
 /*=gfunc sub_shell_str
@@ -717,7 +717,7 @@ ag_scm_shell_str(SCM obj)
 SCM
 ag_scm_sub_shell_str(SCM obj)
 {
-    return shell_stringify(obj, (unsigned)'`');
+    return shell_stringify(obj, (unsigned char)'`');
 }
 
 
