@@ -4,8 +4,12 @@
  *
  *  This module evaluates macro expressions.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -28,6 +32,9 @@ tpl_text(templ_t * tpl, macro_t * mac);
 static void
 tpl_warning(templ_t * tpl, macro_t * mac, char const * msg);
 
+static void
+emit_insertion_file(char const * fname, FILE * outfp);
+
 static int
 expr_type(char * pz);
 /* = = = END-STATIC-FORWARD = = = */
@@ -63,7 +70,7 @@ scm2display(SCM s)
         res = RESOLVE_SCM_PAIR; break;
 
     case GH_TYPE_NUMBER:
-        snprintf(z, sizeof(z), RESOLVE_SCM_NUMBER, AG_SCM_TO_ULONG(s)); break;
+        snprintf(z, sizeof(z), ULONG_FMT, AG_SCM_TO_ULONG(s)); break;
 
     case GH_TYPE_PROCEDURE:
 #ifdef SCM_SUBR_ENTRY
@@ -317,7 +324,6 @@ ag_scm_error_source_line(void)
     return SCM_UNDEFINED;
 }
 
-
 /*=gfunc emit
  *
  * what: emit the text for each argument
@@ -396,6 +402,101 @@ ag_scm_emit(SCM val)
     return SCM_UNDEFINED;
 }
 
+/**
+ * read in a file and write it to the passed in file pointer.
+ *
+ * @param [in]  fname  the name of the file to read
+ * @param [in]  outfp  the file pointer to write the data to.
+ */
+static void
+emit_insertion_file(char const * fname, FILE * outfp)
+{
+    char * txt = load_file(fname);
+    if (txt == NULL) {
+        if (errno == 0)
+            errno = ENOENT;
+        fswarn("loading", fname);
+        return;
+    }
+    if (fputs(txt, outfp) < 0)
+        fserr(AUTOGEN_EXIT_FS_ERROR, "fputs", cur_fpstack->stk_fname);
+
+    if (fflush(outfp) < 0)
+        fserr(AUTOGEN_EXIT_FS_ERROR, "fflush", cur_fpstack->stk_fname);
+    AGFREE(txt);
+}
+
+/*=gfunc insert_file
+ *
+ * what: insert the contents of a (list of) files.
+ *
+ * exparg: alist, list of files to emit, , list
+ *
+ * doc:  Insert the contents of one or more files.
+=*/
+SCM
+ag_scm_insert_file(SCM val)
+{
+    static int depth = 0;
+    static FILE * fp;
+
+    switch (depth) {
+    case 1:
+    {
+        out_stack_t* pSaveFp;
+        unsigned long pnum;
+
+        if (! AG_SCM_NUM_P(val))
+            break;
+
+        pSaveFp = cur_fpstack;
+        pnum    = AG_SCM_TO_ULONG(val);
+
+        for (; pnum > 0; pnum--) {
+            pSaveFp = pSaveFp->stk_prev;
+            if (pSaveFp == NULL)
+                AG_ABEND(aprf(EMIT_INVAL_PORT, AG_SCM_TO_ULONG(val)));
+        }
+
+        fp = pSaveFp->stk_fp;
+        return SCM_UNDEFINED;
+    }
+
+    case 0:
+        fp = cur_fpstack->stk_fp; // initialize the first time through
+        break;
+    }
+
+    depth++;
+    for (;;) {
+        if (val == SCM_UNDEFINED)
+            break;
+
+        if (AG_SCM_NULLP(val))
+            break;
+
+        if (AG_SCM_STRING_P(val)) {
+            emit_insertion_file(ag_scm2zchars(val, "emit val"), fp);
+            break;
+        }
+
+        switch (ag_scm_type_e(val)) {
+        case GH_TYPE_LIST:
+        case GH_TYPE_PAIR:
+            ag_scm_insert_file(SCM_CAR(val));
+            val = SCM_CDR(val);
+            continue;
+
+        default: break;
+        }
+
+        break;
+    }
+
+    depth--;
+    return SCM_UNDEFINED;
+}
+
 /**
  *  The global evaluation function.
  *
@@ -646,7 +747,9 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
     tpl->td_scan = copy;
     return mac + 1;
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
